#!/bin/bash
# Find and enable/disable wireless devices

. /usr/share/acpi-support/state-funcs

toggleAllWirelessStates;

if isAnyWirelessPoweredOn; then
	toshset -bluetooth on
else
	toshset -bluetooth off
fi
